pub struct OpcodeGas {
pub opcode: String,
pub count: u64,
pub gas_used: u64,
}Expand description
Gas information for a single opcode.
Fields
opcode: StringThe name of the opcode
count: u64How many times the opcode was executed
gas_used: u64Combined gas used by all instances of the opcode
For opcodes with constant gas costs, this is the constant opcode gas cost times the count.